import { defaultConfig as defaultConfig$1 } from '@cleavelandprice/ngx-lib';
import { ServiceConfig as ServiceConfig$1, AuthenticationService as AuthenticationService$1 } from '@cleavelandprice/ngx-lib/authentication/token';
import * as i0 from '@angular/core';
import { Injectable, Optional, Component, Inject, Input, NgModule, SkipSelf } from '@angular/core';
import { JwtHelperService } from '@auth0/angular-jwt';
import * as i2 from '@angular/common/http';
import * as i3 from '@cleavelandprice/ngx-lib/sharepoint';
import { ConfirmationComponent } from '@cleavelandprice/ngx-lib/dialog';
import * as i4 from '@angular/forms';
import { UntypedFormGroup, UntypedFormControl, Validators, ReactiveFormsModule } from '@angular/forms';
import * as i1 from '@angular/material/dialog';
import { MAT_DIALOG_DATA, MatDialogModule } from '@angular/material/dialog';
import * as i3$1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i5 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i6 from '@angular/material/form-field';
import { MatFormFieldModule } from '@angular/material/form-field';
import * as i7 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';
import * as i8 from '@angular/material/input';
import { MatInputModule } from '@angular/material/input';
import * as i9 from '@angular/material/progress-spinner';
import { MatProgressSpinnerModule } from '@angular/material/progress-spinner';

const defaultConfig = {
    apiUrl: defaultConfig$1.apiUrl,
    authenticateEndpoint: '/authenticate/token',
    tokenName: 'token',
    deferTokenValidation: true
};

class ServiceConfig extends ServiceConfig$1 {
}

class AuthenticationService extends AuthenticationService$1 {
    //#region Lifecycle
    // If a ServiceConfig object is not provided when the module is imported, then default values are pulled in from default-config.ts.
    constructor(config, http, sharePointService) {
        config = Object.assign(Object.assign(Object.assign({}, defaultConfig), config), { 
            // Need to force deferTokenValidation here because if a custom config was passed in, deferTokenValidation would have defaulted to false since it's the default boolean value
            // If a custom config wasn't passed in, then deferTokenValidation would have been true from defaultConfig
            deferTokenValidation: true });
        super(config, http);
        this.config = config;
        this.http = http;
        this.sharePointService = sharePointService;
        this.checkForExistingToken();
    }
    //#endregion
    //#region Utilities
    validateUser(token) {
        const jwtHelper = new JwtHelperService();
        const decoded = jwtHelper.decodeToken(token);
        if (jwtHelper.isTokenExpired(token)) {
            this.logout();
            return;
        }
        this.authenticatedUser = {
            admin: decoded.role === 'Admin',
            displayName: decoded.displayName,
            accountName: decoded.winaccountname,
            distinguishedName: decoded.distinguishedName,
            employeeNumber: decoded.employeeNumber,
            memberOf: decoded.memberOf
        };
        localStorage.setItem(this.config.tokenName, token);
        this.getPhoto();
        this.authenticated = true;
        this.authenticatedChanged.emit(this.authenticated);
        this.authenticating = false;
        this.authenticatingChanged.emit(this.authenticating);
    }
    getPhoto() {
        this.sharePointService.getPhotos()
            .subscribe(photos => {
            var _a;
            // The user may have been logged out by the time the photos came back
            if (!((_a = this.authenticatedUser) === null || _a === void 0 ? void 0 : _a.employeeNumber)) {
                return;
            }
            const photo = photos.find(pic => pic.employeeNumber === +this.authenticatedUser.employeeNumber);
            if (photo) {
                this.authenticatedUser.photoUrl = photo.encodedAbsUrl;
            }
        });
    }
}
AuthenticationService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: AuthenticationService, deps: [{ token: ServiceConfig, optional: true }, { token: i2.HttpClient }, { token: i3.SharePointService }], target: i0.ɵɵFactoryTarget.Injectable });
AuthenticationService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: AuthenticationService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: AuthenticationService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () {
        return [{ type: ServiceConfig, decorators: [{
                        type: Optional
                    }] }, { type: i2.HttpClient }, { type: i3.SharePointService }];
    } });

class LoginFormComponent {
    constructor(data, dialogRef, authenticationService) {
        var _a;
        this.dialogRef = dialogRef;
        this.authenticationService = authenticationService;
        this.errorMessage = null;
        this.form = new UntypedFormGroup({
            username: new UntypedFormControl(null, [Validators.required]),
            password: new UntypedFormControl(null, [Validators.required]),
            adminGroup: new UntypedFormControl()
        });
        (_a = this.form.get('adminGroup')) === null || _a === void 0 ? void 0 : _a.setValue(data.adminGroup);
    }
    ngOnInit() {
        this.authenticatedChangedSubscription = this.authenticationService.authenticatedChanged
            .subscribe(this.authChangedHandler.bind(this));
        this.authenticationErrorSubscription = this.authenticationService.authenticationError
            .subscribe(this.errorHandler.bind(this));
    }
    ngOnDestroy() {
        this.authenticationErrorSubscription.unsubscribe();
        this.authenticatedChangedSubscription.unsubscribe();
    }
    authenticate() {
        this.errorMessage = null;
        const { username, password, adminGroup } = this.form.value;
        this.authenticationService.login(username, password, adminGroup);
    }
    authChangedHandler(authenticated) {
        if (authenticated) {
            this.dialogRef.close();
        }
    }
    errorHandler(err) {
        console.log('Authentication error', err);
        this.errorMessage = `${err.name}: ${err.statusText}`;
    }
}
LoginFormComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: LoginFormComponent, deps: [{ token: MAT_DIALOG_DATA }, { token: i1.MatDialogRef }, { token: AuthenticationService }], target: i0.ɵɵFactoryTarget.Component });
LoginFormComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.1", type: LoginFormComponent, selector: "authentication-login-form", ngImport: i0, template: "<h2 mat-dialog-title>\r\n    <span *ngIf=\"!authenticationService.authenticating\">Login</span>\r\n    <span *ngIf=\"authenticationService.authenticating\">Authenticating...</span>\r\n</h2>\r\n\r\n<mat-dialog-content>\r\n    <div id=\"spinner\" *ngIf=\"authenticationService.authenticating\">\r\n        <mat-progress-spinner color=\"primary\" mode=\"indeterminate\"></mat-progress-spinner>\r\n    </div>\r\n\r\n    <form *ngIf=\"!authenticationService.authenticating\" [formGroup]=\"form\">\r\n        <mat-form-field>\r\n            <input matInput formControlName=\"username\" placeholder=\"Username\" (keyup.enter)=\"authenticate()\">\r\n        </mat-form-field>\r\n\r\n        <mat-form-field>\r\n            <input matInput formControlName=\"password\" type=\"password\" placeholder=\"Password\" (keyup.enter)=\"authenticate()\">\r\n        </mat-form-field>\r\n    </form>\r\n\r\n    <div *ngIf=\"!authenticationService.authenticating && errorMessage\" id=\"error\">\r\n        {{ errorMessage }}\r\n    </div>\r\n</mat-dialog-content>\r\n\r\n<mat-dialog-actions *ngIf=\"!authenticationService.authenticating\">\r\n    <button mat-raised-button color=\"primary\" (click)=\"authenticate()\"\r\n        [disabled]=\"form.invalid\">\r\n        <mat-icon fontIcon=\"done\"></mat-icon>\r\n        <span>OK</span>\r\n    </button>\r\n\r\n    <button mat-raised-button (click)=\"dialogRef.close()\">\r\n        <mat-icon fontIcon=\"close\"></mat-icon>\r\n        <span>Cancel</span>\r\n    </button>\r\n</mat-dialog-actions>", styles: ["#spinner{width:100%;height:100%;display:flex;justify-content:center;align-items:center}form{display:grid;gap:1rem}mat-dialog-actions{display:grid;justify-content:center;grid-template-columns:auto auto;gap:1rem}#error{color:red}\n", ".material-icons{font-family:Material Icons;font-weight:400;font-style:normal;font-size:24px;display:inline-block;line-height:1;text-transform:none;letter-spacing:normal;word-wrap:normal;white-space:nowrap;direction:ltr;-webkit-font-smoothing:antialiased;text-rendering:optimizeLegibility;-moz-osx-font-smoothing:grayscale;font-feature-settings:\"liga\"}\n"], dependencies: [{ kind: "directive", type: i3$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i4.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i4.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i4.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i4.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i4.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i4.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "component", type: i5.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { kind: "directive", type: i1.MatDialogTitle, selector: "[mat-dialog-title], [matDialogTitle]", inputs: ["id"], exportAs: ["matDialogTitle"] }, { kind: "directive", type: i1.MatDialogContent, selector: "[mat-dialog-content], mat-dialog-content, [matDialogContent]" }, { kind: "directive", type: i1.MatDialogActions, selector: "[mat-dialog-actions], mat-dialog-actions, [matDialogActions]", inputs: ["align"] }, { kind: "component", type: i6.MatFormField, selector: "mat-form-field", inputs: ["color", "appearance", "hideRequiredMarker", "hintLabel", "floatLabel"], exportAs: ["matFormField"] }, { kind: "component", type: i7.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "directive", type: i8.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly"], exportAs: ["matInput"] }, { kind: "component", type: i9.MatProgressSpinner, selector: "mat-progress-spinner, mat-spinner", inputs: ["color", "diameter", "strokeWidth", "mode", "value"], exportAs: ["matProgressSpinner"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: LoginFormComponent, decorators: [{
            type: Component,
            args: [{ selector: 'authentication-login-form', template: "<h2 mat-dialog-title>\r\n    <span *ngIf=\"!authenticationService.authenticating\">Login</span>\r\n    <span *ngIf=\"authenticationService.authenticating\">Authenticating...</span>\r\n</h2>\r\n\r\n<mat-dialog-content>\r\n    <div id=\"spinner\" *ngIf=\"authenticationService.authenticating\">\r\n        <mat-progress-spinner color=\"primary\" mode=\"indeterminate\"></mat-progress-spinner>\r\n    </div>\r\n\r\n    <form *ngIf=\"!authenticationService.authenticating\" [formGroup]=\"form\">\r\n        <mat-form-field>\r\n            <input matInput formControlName=\"username\" placeholder=\"Username\" (keyup.enter)=\"authenticate()\">\r\n        </mat-form-field>\r\n\r\n        <mat-form-field>\r\n            <input matInput formControlName=\"password\" type=\"password\" placeholder=\"Password\" (keyup.enter)=\"authenticate()\">\r\n        </mat-form-field>\r\n    </form>\r\n\r\n    <div *ngIf=\"!authenticationService.authenticating && errorMessage\" id=\"error\">\r\n        {{ errorMessage }}\r\n    </div>\r\n</mat-dialog-content>\r\n\r\n<mat-dialog-actions *ngIf=\"!authenticationService.authenticating\">\r\n    <button mat-raised-button color=\"primary\" (click)=\"authenticate()\"\r\n        [disabled]=\"form.invalid\">\r\n        <mat-icon fontIcon=\"done\"></mat-icon>\r\n        <span>OK</span>\r\n    </button>\r\n\r\n    <button mat-raised-button (click)=\"dialogRef.close()\">\r\n        <mat-icon fontIcon=\"close\"></mat-icon>\r\n        <span>Cancel</span>\r\n    </button>\r\n</mat-dialog-actions>", styles: ["#spinner{width:100%;height:100%;display:flex;justify-content:center;align-items:center}form{display:grid;gap:1rem}mat-dialog-actions{display:grid;justify-content:center;grid-template-columns:auto auto;gap:1rem}#error{color:red}\n", ".material-icons{font-family:Material Icons;font-weight:400;font-style:normal;font-size:24px;display:inline-block;line-height:1;text-transform:none;letter-spacing:normal;word-wrap:normal;white-space:nowrap;direction:ltr;-webkit-font-smoothing:antialiased;text-rendering:optimizeLegibility;-moz-osx-font-smoothing:grayscale;font-feature-settings:\"liga\"}\n"] }]
        }], ctorParameters: function () {
        return [{ type: undefined, decorators: [{
                        type: Inject,
                        args: [MAT_DIALOG_DATA]
                    }] }, { type: i1.MatDialogRef }, { type: AuthenticationService }];
    } });

class LoginComponent {
    constructor(dialog, authenticationService) {
        this.dialog = dialog;
        this.authenticationService = authenticationService;
    }
    login() {
        this.dialog.open(LoginFormComponent, {
            data: { adminGroup: this.adminGroup }
        });
    }
    confirmLogout() {
        this.dialog.open(ConfirmationComponent, {
            data: { message: `Are you sure you want to logout?` }
        })
            .afterClosed()
            .subscribe(result => {
            if (result) {
                this.authenticationService.logout();
            }
        });
    }
}
LoginComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: LoginComponent, deps: [{ token: i1.MatDialog }, { token: AuthenticationService }], target: i0.ɵɵFactoryTarget.Component });
LoginComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.1", type: LoginComponent, selector: "authentication-login", inputs: { adminGroup: "adminGroup" }, ngImport: i0, template: "<div id=\"user-id\">\r\n    <!-- Logged out -->\r\n    <mat-icon *ngIf=\"!authenticationService.authenticated\"\r\n        fontIcon=\"account_circle\"\r\n        matTooltip=\"Login\"\r\n        (click)=\"login()\">\r\n    </mat-icon>\r\n\r\n    <!-- Logged in -->\r\n    <ng-container *ngIf=\"authenticationService.authenticated\">\r\n        <!-- With photo -->\r\n        <img *ngIf=\"authenticationService.authenticatedUser?.photoUrl\"\r\n            id=\"authenticated-user-image\"\r\n            [src]=\"authenticationService.authenticatedUser?.photoUrl\"\r\n            matTooltip=\"Logout\"\r\n            (click)=\"confirmLogout()\" />\r\n    \r\n        <!-- Without photo -->\r\n        <mat-icon *ngIf=\"!authenticationService.authenticatedUser?.photoUrl\"\r\n            fontIcon=\"account_circle\"\r\n            matTooltip=\"Logout\"\r\n            (click)=\"confirmLogout()\">\r\n        </mat-icon>\r\n    \r\n        <!-- Name -->\r\n        <div id=\"user-name\">\r\n            {{ authenticationService.authenticatedUser?.displayName }}\r\n        </div>\r\n    </ng-container>\r\n</div>", styles: ["#user-id{display:flex;height:2em;padding:.3em;font-family:Verdana,Geneva,Tahoma,sans-serif}mat-icon{font-size:2em!important;height:2em!important;width:2em!important}img{border-radius:100%;width:2em;height:2em}#user-id>div{display:flex;align-items:center;height:100%;margin-left:.75em;font-size:1.15em}\n", ".material-icons{font-family:Material Icons;font-weight:400;font-style:normal;font-size:24px;display:inline-block;line-height:1;text-transform:none;letter-spacing:normal;word-wrap:normal;white-space:nowrap;direction:ltr;-webkit-font-smoothing:antialiased;text-rendering:optimizeLegibility;-moz-osx-font-smoothing:grayscale;font-feature-settings:\"liga\"}\n"], dependencies: [{ kind: "directive", type: i3$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i7.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: LoginComponent, decorators: [{
            type: Component,
            args: [{ selector: 'authentication-login', template: "<div id=\"user-id\">\r\n    <!-- Logged out -->\r\n    <mat-icon *ngIf=\"!authenticationService.authenticated\"\r\n        fontIcon=\"account_circle\"\r\n        matTooltip=\"Login\"\r\n        (click)=\"login()\">\r\n    </mat-icon>\r\n\r\n    <!-- Logged in -->\r\n    <ng-container *ngIf=\"authenticationService.authenticated\">\r\n        <!-- With photo -->\r\n        <img *ngIf=\"authenticationService.authenticatedUser?.photoUrl\"\r\n            id=\"authenticated-user-image\"\r\n            [src]=\"authenticationService.authenticatedUser?.photoUrl\"\r\n            matTooltip=\"Logout\"\r\n            (click)=\"confirmLogout()\" />\r\n    \r\n        <!-- Without photo -->\r\n        <mat-icon *ngIf=\"!authenticationService.authenticatedUser?.photoUrl\"\r\n            fontIcon=\"account_circle\"\r\n            matTooltip=\"Logout\"\r\n            (click)=\"confirmLogout()\">\r\n        </mat-icon>\r\n    \r\n        <!-- Name -->\r\n        <div id=\"user-name\">\r\n            {{ authenticationService.authenticatedUser?.displayName }}\r\n        </div>\r\n    </ng-container>\r\n</div>", styles: ["#user-id{display:flex;height:2em;padding:.3em;font-family:Verdana,Geneva,Tahoma,sans-serif}mat-icon{font-size:2em!important;height:2em!important;width:2em!important}img{border-radius:100%;width:2em;height:2em}#user-id>div{display:flex;align-items:center;height:100%;margin-left:.75em;font-size:1.15em}\n", ".material-icons{font-family:Material Icons;font-weight:400;font-style:normal;font-size:24px;display:inline-block;line-height:1;text-transform:none;letter-spacing:normal;word-wrap:normal;white-space:nowrap;direction:ltr;-webkit-font-smoothing:antialiased;text-rendering:optimizeLegibility;-moz-osx-font-smoothing:grayscale;font-feature-settings:\"liga\"}\n"] }]
        }], ctorParameters: function () { return [{ type: i1.MatDialog }, { type: AuthenticationService }]; }, propDecorators: { adminGroup: [{
                type: Input
            }] } });

class GuiModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('GuiModule is already loaded. Import it in the AppModule only');
        }
    }
    static forRoot(config) {
        return {
            ngModule: GuiModule,
            providers: [
                AuthenticationService,
                { provide: ServiceConfig, useValue: config }
            ]
        };
    }
}
GuiModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: GuiModule, deps: [{ token: GuiModule, optional: true, skipSelf: true }], target: i0.ɵɵFactoryTarget.NgModule });
GuiModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.1", ngImport: i0, type: GuiModule, declarations: [LoginComponent,
        LoginFormComponent], imports: [CommonModule,
        ReactiveFormsModule,
        MatButtonModule,
        MatDialogModule,
        MatFormFieldModule,
        MatIconModule,
        MatInputModule,
        MatProgressSpinnerModule], exports: [LoginComponent,
        LoginFormComponent] });
GuiModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: GuiModule, imports: [CommonModule,
        ReactiveFormsModule,
        MatButtonModule,
        MatDialogModule,
        MatFormFieldModule,
        MatIconModule,
        MatInputModule,
        MatProgressSpinnerModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: GuiModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        LoginComponent,
                        LoginFormComponent
                    ],
                    imports: [
                        CommonModule,
                        ReactiveFormsModule,
                        MatButtonModule,
                        MatDialogModule,
                        MatFormFieldModule,
                        MatIconModule,
                        MatInputModule,
                        MatProgressSpinnerModule
                    ],
                    exports: [
                        LoginComponent,
                        LoginFormComponent
                    ]
                }]
        }], ctorParameters: function () {
        return [{ type: GuiModule, decorators: [{
                        type: Optional
                    }, {
                        type: SkipSelf
                    }] }];
    } });

/**
 * Generated bundle index. Do not edit.
 */

export { AuthenticationService, GuiModule, LoginComponent, LoginFormComponent, ServiceConfig, defaultConfig };
//# sourceMappingURL=cleavelandprice-ngx-lib-authentication-token-gui.mjs.map
