import { defaultConfig as defaultConfig$1 } from '@cleavelandprice/ngx-lib';
import * as i0 from '@angular/core';
import { Injectable, Optional, NgModule, SkipSelf } from '@angular/core';
import { of } from 'rxjs';
import moment from 'moment';
import * as i2 from '@angular/common/http';
import { CommonModule } from '@angular/common';

const defaultConfig = {
    apiUrl: defaultConfig$1.apiUrl,
    usersEndpoint: '/sharepoint/users',
    listItemsEndpoint: '/sharepoint/listitems',
    username: 'viewer',
    password: 'viewer',
    photos: {
        site: 'https://sharepoint.cleavelandprice.com/digitaldisplay',
        list: 'Employee Thumbnail Photos',
        additionalPropertiesToRetrieve: [
            'EncodedAbsUrl'
        ]
    },
    caching: {
        enabled: true,
        lifeMinutes: 720
    },
    logging: {
        dataCached: true,
        cachedDataReturned: true,
        freshDataReturned: true,
        cacheCleared: true
    }
};

class ServiceConfig {
}

class SharePointService {
    //#endregion
    //#region Initialization
    // If a ServiceConfig object is not provided when the module is imported, then default values are pulled in from default-config.ts.
    constructor(config, http) {
        this.config = config;
        this.http = http;
        this.cache = null;
        this.defaultCacheLifeMinutes = 720;
        this.config = Object.assign(Object.assign({}, defaultConfig), this.config);
        this.configureCaching();
        this.configureLogging();
    }
    //#region Utilities
    cacheExpired(cache) {
        var _a, _b;
        if (!cache) {
            return true;
        }
        const lifeMinutes = (_b = (_a = this.config.caching) === null || _a === void 0 ? void 0 : _a.lifeMinutes) !== null && _b !== void 0 ? _b : this.defaultCacheLifeMinutes;
        const expiration = moment(cache.lastUpdate)
            .add(lifeMinutes, 'minutes');
        return moment().isAfter(expiration);
    }
    configureCaching() {
        var _a;
        // If caching config is missing entirely, give it a default
        this.config.caching = (_a = this.config.caching) !== null && _a !== void 0 ? _a : {
            enabled: false,
            lifeMinutes: this.defaultCacheLifeMinutes
        };
        this.cache = {
            photos: null,
            users: null
        };
    }
    configureLogging() {
        var _a;
        // If logging config is missing entirely, give it a default
        this.config.logging = (_a = this.config.logging) !== null && _a !== void 0 ? _a : {
            dataCached: false,
            cachedDataReturned: false,
            freshDataReturned: false,
            cacheCleared: false
        };
    }
    //#endregion
    getListItems(request) {
        var _a, _b, _c, _d;
        const apiUrl = (_b = (_a = this.config) === null || _a === void 0 ? void 0 : _a.apiUrl) !== null && _b !== void 0 ? _b : defaultConfig.apiUrl;
        const endpoint = (_d = (_c = this.config) === null || _c === void 0 ? void 0 : _c.listItemsEndpoint) !== null && _d !== void 0 ? _d : defaultConfig.listItemsEndpoint;
        return this.http.post(`${apiUrl}${endpoint}`, request);
    }
    getPhotos() {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m;
        const request = {
            username: (_b = (_a = this.config) === null || _a === void 0 ? void 0 : _a.username) !== null && _b !== void 0 ? _b : defaultConfig.username,
            password: (_d = (_c = this.config) === null || _c === void 0 ? void 0 : _c.password) !== null && _d !== void 0 ? _d : defaultConfig.password,
            site: (_f = (_e = this.config) === null || _e === void 0 ? void 0 : _e.photos.site) !== null && _f !== void 0 ? _f : defaultConfig.photos.site,
            list: (_h = (_g = this.config) === null || _g === void 0 ? void 0 : _g.photos.list) !== null && _h !== void 0 ? _h : defaultConfig.photos.list,
            additionalPropertiesToRetrieve: defaultConfig.photos.additionalPropertiesToRetrieve
        };
        const observable$ = this.getListItems(request);
        if ((_j = this.config.caching) === null || _j === void 0 ? void 0 : _j.enabled) {
            if (this.cacheExpired((_k = this.cache) === null || _k === void 0 ? void 0 : _k.photos)) {
                // Get the data and cache it
                observable$.subscribe(data => {
                    var _a, _b, _c;
                    this.cache.photos = {
                        data,
                        lastUpdate: moment()
                    };
                    if ((_a = this.config.logging) === null || _a === void 0 ? void 0 : _a.dataCached) {
                        const lifeMinutes = (_c = (_b = this.config.caching) === null || _b === void 0 ? void 0 : _b.lifeMinutes) !== null && _c !== void 0 ? _c : this.defaultCacheLifeMinutes;
                        console.log(`Photos cached for ${lifeMinutes} minutes`);
                    }
                });
            }
            else {
                // Cache exists and hasn't expired yet
                if ((_l = this.config.logging) === null || _l === void 0 ? void 0 : _l.cachedDataReturned) {
                    console.log('Returning cached photos');
                }
                return of(this.cache.photos.data);
            }
        }
        // Cache is either disabled or expired, return data from API
        if ((_m = this.config.logging) === null || _m === void 0 ? void 0 : _m.freshDataReturned) {
            console.log('Returning fresh photos');
        }
        return observable$;
    }
    getUsers(request, id) {
        var _a, _b, _c, _d, _e, _f, _g;
        const apiUrl = (_b = (_a = this.config) === null || _a === void 0 ? void 0 : _a.apiUrl) !== null && _b !== void 0 ? _b : defaultConfig.apiUrl;
        const endpoint = (_d = (_c = this.config) === null || _c === void 0 ? void 0 : _c.usersEndpoint) !== null && _d !== void 0 ? _d : defaultConfig.usersEndpoint;
        const observable$ = this.http.post(`${apiUrl}${endpoint}/${id !== null && id !== void 0 ? id : ''}`, request);
        //#region Single user
        if (id) {
            return observable$;
        }
        //#endregion
        //#region Multiple users
        if ((_e = this.config.caching) === null || _e === void 0 ? void 0 : _e.enabled) {
            if (this.cacheExpired(this.cache.users)) {
                // Get the data and cache it
                observable$.subscribe(data => {
                    var _a, _b, _c;
                    this.cache.users = {
                        data: data,
                        lastUpdate: moment()
                    };
                    if ((_a = this.config.logging) === null || _a === void 0 ? void 0 : _a.dataCached) {
                        const lifeMinutes = (_c = (_b = this.config.caching) === null || _b === void 0 ? void 0 : _b.lifeMinutes) !== null && _c !== void 0 ? _c : this.defaultCacheLifeMinutes;
                        console.log(`Users cached for ${lifeMinutes} minutes`);
                    }
                });
            }
            else {
                // Cache exists and hasn't expired yet
                if ((_f = this.config.logging) === null || _f === void 0 ? void 0 : _f.cachedDataReturned) {
                    console.log('Returning cached users');
                }
                return of(this.cache.users.data);
            }
        }
        // Cache is either disabled or expired, return data from API
        if ((_g = this.config.logging) === null || _g === void 0 ? void 0 : _g.freshDataReturned) {
            console.log('Returning fresh users');
        }
        return observable$;
        //#endregion
    }
    clearCache() {
        var _a;
        this.cache = null;
        if ((_a = this.config.logging) === null || _a === void 0 ? void 0 : _a.cacheCleared) {
            console.log('Cache cleared');
        }
    }
}
SharePointService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: SharePointService, deps: [{ token: ServiceConfig, optional: true }, { token: i2.HttpClient }], target: i0.ɵɵFactoryTarget.Injectable });
SharePointService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: SharePointService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: SharePointService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () {
        return [{ type: ServiceConfig, decorators: [{
                        type: Optional
                    }] }, { type: i2.HttpClient }];
    } });

class SharePointModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('SharePointModule is already loaded. Import it in the AppModule only');
        }
    }
    static forRoot(config) {
        return {
            ngModule: SharePointModule,
            providers: [
                SharePointService,
                { provide: ServiceConfig, useValue: config }
            ]
        };
    }
}
SharePointModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: SharePointModule, deps: [{ token: SharePointModule, optional: true, skipSelf: true }], target: i0.ɵɵFactoryTarget.NgModule });
SharePointModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.1", ngImport: i0, type: SharePointModule, imports: [CommonModule] });
SharePointModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: SharePointModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: SharePointModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [],
                    imports: [
                        CommonModule
                    ]
                }]
        }], ctorParameters: function () {
        return [{ type: SharePointModule, decorators: [{
                        type: Optional
                    }, {
                        type: SkipSelf
                    }] }];
    } });

/**
 * Generated bundle index. Do not edit.
 */

export { ServiceConfig, SharePointModule, SharePointService, defaultConfig };
//# sourceMappingURL=cleavelandprice-ngx-lib-sharepoint.mjs.map
